display

package
v0.0.0-...-75edfd4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 19, 2026 License: AGPL-3.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Manager

type Manager struct {
	// contains filtered or unexported fields
}

Manager handles the virtual display window and rendering

func NewManager

func NewManager(cfg *config.DisplayConfig) (*Manager, error)

NewManager creates a new display manager

func (*Manager) ClearDisplay

func (m *Manager) ClearDisplay() error

ClearDisplay clears the display window (shows black screen)

func (*Manager) GetWindowID

func (m *Manager) GetWindowID() uint32

GetWindowID returns the display window ID

func (*Manager) IsRunning

func (m *Manager) IsRunning() bool

IsRunning returns whether the display is currently running

func (*Manager) RenderWindow

func (m *Manager) RenderWindow(windowID uint32) error

RenderWindow captures and renders a window to the display

func (*Manager) SetWindowCapturer

func (m *Manager) SetWindowCapturer(capturer WindowCapturer)

SetWindowCapturer sets the window capturer to use for screenshots

func (*Manager) Start

func (m *Manager) Start() error

Start creates and shows the virtual display window

func (*Manager) Stop

func (m *Manager) Stop()

Stop closes the virtual display window

func (*Manager) UpdateLoop

func (m *Manager) UpdateLoop(getCurrentWindow func() *config.WindowInfo, isAllowlisted func(*config.WindowInfo) bool)

UpdateLoop continuously updates the display based on focused window

type WindowCapturer

type WindowCapturer interface {
	CaptureWindowScreenshot(windowID uint32) ([]byte, error)
}

WindowCapturer interface for capturing window screenshots

Jump to