Documentation
¶
Index ¶
- type Manager
- func (m *Manager) ClearDisplay() error
- func (m *Manager) GetWindowID() uint32
- func (m *Manager) IsRunning() bool
- func (m *Manager) RenderWindow(windowID uint32) error
- func (m *Manager) SetWindowCapturer(capturer WindowCapturer)
- func (m *Manager) Start() error
- func (m *Manager) Stop()
- func (m *Manager) UpdateLoop(getCurrentWindow func() *config.WindowInfo, ...)
- type WindowCapturer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
Manager handles the virtual display window and rendering
func NewManager ¶
func NewManager(cfg *config.DisplayConfig) (*Manager, error)
NewManager creates a new display manager
func (*Manager) ClearDisplay ¶
ClearDisplay clears the display window (shows black screen)
func (*Manager) GetWindowID ¶
GetWindowID returns the display window ID
func (*Manager) RenderWindow ¶
RenderWindow captures and renders a window to the display
func (*Manager) SetWindowCapturer ¶
func (m *Manager) SetWindowCapturer(capturer WindowCapturer)
SetWindowCapturer sets the window capturer to use for screenshots
func (*Manager) UpdateLoop ¶
func (m *Manager) UpdateLoop(getCurrentWindow func() *config.WindowInfo, isAllowlisted func(*config.WindowInfo) bool)
UpdateLoop continuously updates the display based on focused window
type WindowCapturer ¶
WindowCapturer interface for capturing window screenshots
Click to show internal directories.
Click to hide internal directories.